==> haskell-hspec-megaparsec-2.0.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.0
id: hspec-megaparsec-2.0.0-5s2uErNWfhVEZ1curWzgoI
key: hspec-megaparsec-2.0.0-5s2uErNWfhVEZ1curWzgoI
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 22095765175e94da3a934ce9c64c06c0
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.0
hs-libraries: HShspec-megaparsec-2.0.0-5s2uErNWfhVEZ1curWzgoI
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.0.0-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 2.0.0
id: hspec-megaparsec-2.0.0-FUcwElem8vB46XhRZnKVAe
key: hspec-megaparsec-2.0.0-FUcwElem8vB46XhRZnKVAe
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 8d89966b2f37b5e2b2c5f95f086b90b6
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-megaparsec-2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-megaparsec-2.0.0
hs-libraries: HShspec-megaparsec-2.0.0-FUcwElem8vB46XhRZnKVAe
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-7.0.5-2iUcnvfGmgfB7XKEYeVDVV
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
